pub struct ComponentData {
value: Box<dyn Component>,
}Expand description
A type-erased component value.
Component values retain their concrete Rust type and can be recovered with
Self::downcast_ref.
Fields
value: Box<dyn Component>Implementations
Sourceimpl ComponentData
impl ComponentData
Sourcepub fn downcast_ref<T: DowncastType>(&self) -> Option<&T>
pub fn downcast_ref<T: DowncastType>(&self) -> Option<&T>
Returns the concrete value when it has type T.
Sourcepub fn type_key(&self) -> DowncastTypeKey
pub fn type_key(&self) -> DowncastTypeKey
Returns the concrete type key.